@@ -1,4 +1,4 @@
-//@line 39 "/home/gscrivano/icecat/301/browser/components/feeds/src/WebContentConverter.js"
+//@line 39 "/icecat-3.0.4-g1/browser/components/feeds/src/WebContentConverter.js"
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
@@ -850,10 +850,10 @@ WebContentConverterRegistrar.prototype = {
         getService(Ci.nsIObserverService);
     switch (topic) {
     case "app-startup":
-      os.addObserver(this, "profile-after-change", false);
+      os.addObserver(this, "browser-ui-startup-complete", false);
       break;
-    case "profile-after-change":
-      os.removeObserver(this, "profile-after-change");
+    case "browser-ui-startup-complete":
+      os.removeObserver(this, "browser-ui-startup-complete");
       this._init();
       break;
     }
@@ -908,7 +908,7 @@ function NSGetModule(cm, file) {
   return XPCOMUtils.generateModule([WebContentConverterRegistrar]);
 }
 
-//@line 44 "/home/gscrivano/icecat/301/toolkit/content/debug.js"
+//@line 44 "/icecat-3.0.4-g1/toolkit/content/debug.js"
 
 var EXPORTED_SYMBOLS = ["NS_ASSERT"];
 
@@ -990,5 +990,5 @@ function NS_ASSERT(condition, message) {
            getService(Components.interfaces.nsIPromptService);
   ps.alert(source, "Assertion Failed", assertionText + stackText);
 }
-//@line 949 "/home/gscrivano/icecat/301/browser/components/feeds/src/WebContentConverter.js"
+//@line 949 "/icecat-3.0.4-g1/browser/components/feeds/src/WebContentConverter.js"
 
