@@ -134,7 +134,7 @@ pref("gfx.color_management.display_profile", "");
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 138 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 138 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -147,7 +147,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 154 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 154 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -343,6 +343,8 @@ pref("capability.policy.mailnews.*.data.get", "noAccess");
 pref("capability.policy.mailnews.*.getAttribute", "noAccess");
 pref("capability.policy.mailnews.HTMLDivElement.getAttribute", "sameOrigin");
 pref("capability.policy.mailnews.*.getAttributeNS", "noAccess");
+pref("capability.policy.mailnews.*.getAttributeNode", "noAccess");
+pref("capability.policy.mailnews.*.getAttributeNodeNS", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItem", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItemNS", "noAccess");
 pref("capability.policy.mailnews.*.host.get", "noAccess");
@@ -356,11 +358,13 @@ pref("capability.policy.mailnews.*.protocol.get", "noAccess");
 pref("capability.policy.mailnews.*.src.get", "noAccess");
 pref("capability.policy.mailnews.*.substringData.get", "noAccess");
 pref("capability.policy.mailnews.*.text.get", "noAccess");
+pref("capability.policy.mailnews.*.textContent", "noAccess");
 pref("capability.policy.mailnews.*.title.get", "noAccess");
 pref("capability.policy.mailnews.DOMException.toString", "noAccess");
 pref("capability.policy.mailnews.HTMLAnchorElement.toString", "noAccess");
 pref("capability.policy.mailnews.HTMLDocument.domain", "noAccess");
 pref("capability.policy.mailnews.HTMLDocument.URL", "noAccess");
+pref("capability.policy.mailnews.*.documentURI", "noAccess");
 pref("capability.policy.mailnews.Location.toString", "noAccess");
 pref("capability.policy.mailnews.Range.toString", "noAccess");
 pref("capability.policy.mailnews.Window.blur", "noAccess");
@@ -523,7 +527,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 532 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 536 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -639,6 +643,7 @@ pref("network.IDN_show_punycode", false);
 
 // ccTLDs
 pref("network.IDN.whitelist.ac", true);
+pref("network.IDN.whitelist.ar", true);
 pref("network.IDN.whitelist.at", true);
 pref("network.IDN.whitelist.br", true);
 pref("network.IDN.whitelist.ch", true);
@@ -752,7 +757,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 766 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 771 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -776,9 +781,9 @@ pref("network.hosts.nntp_server",           "news.mozilla.org");
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 791 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 796 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 798 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 803 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1112,15 +1117,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1514 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 1520 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 1930 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 1937 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 2127 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2134 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 2218 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2225 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 2221 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2228 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1205,7 +1210,9 @@ pref("font.name.serif.ko", "serif");
 pref("font.name.sans-serif.ko", "sans-serif");
 pref("font.name.monospace.ko", "monospace");
 
-// th
+pref("font.name.serif.th", "serif");
+pref("font.name.sans-serif.th", "sans-serif");
+pref("font.name.monospace.th", "monospace");
 
 pref("font.name.serif.tr", "serif");
 pref("font.name.sans-serif.tr", "sans-serif");
@@ -1269,7 +1276,8 @@ pref("font.size.fixed.ko", 16);
 
 pref("font.default.th", "serif");
 pref("font.size.variable.th", 16);
-pref("font.size.fixed.th", 12);
+pref("font.size.fixed.th", 13);
+pref("font.minimum-size.th", 13);
 
 pref("font.default.tr", "serif");
 pref("font.size.variable.tr", 16);
@@ -1377,15 +1385,15 @@ pref("print.postscript.paper_size",    "letter");
 pref("print.postscript.orientation",   "portrait");
 pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2480 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2490 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 2548 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2558 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 2574 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2584 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 2594 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2604 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
-//@line 2602 "/home/gscrivano/icecat/301/modules/libpref/src/init/all.js"
+//@line 2612 "/icecat-3.0.4-g1/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
